@@ -38,7 +38,7 @@ def check_status(app):
             packages = app.default_packages_master
             if packages:
                 try:
-                    output = subprocess.check_output(['dpkg', '-s'] + packages, stderr=subprocess.STDOUT).decode('utf-8')
+                    output = subprocess.check_output(['dpkg', '-s', *packages], stderr=subprocess.STDOUT).decode('utf-8')
                 except subprocess.CalledProcessError:
                     utils.fail('ERROR: MasterPackages are not installed!')
                 else:
@@ -68,7 +68,7 @@ def check_webinterface(app):
 
 def _check_url(url):
     print('       Checking', url)
-    import lxml  # noqa: S410
+    import lxml
     import requests
     requests_timeout = 30
     r = requests.get(url, timeout=requests_timeout, verify=False)  # noqa: S501
