@@ -28,7 +28,7 @@ def test_app_without_package(appcenter):
 
         app.install()
 
-        app.verify(joined=False)
+        app.verify()
 
         app.configure_tinyapp_modproxy()
         app.verify_basic_modproxy_settings_tinyapp()
